==> zerohertzLib-0.3.2.tar.gz: zerohertzLib-0.3.2/README.md <==
<p align="center">
    <img src="https://github-production-user-asset-6210df.s3.amazonaws.com/42334717/284166558-0ba4b755-39cc-48ee-ba3b-5c02f54c4ca7.png">
</p>

<h2 align = "center">
    ⚡ Zerohertz's Library ⚡
</h2>

<p align="center">
    </br>
    <a href="https://github.com/Zerohertz/zerohertzLib">
        <img src="https://img.shields.io/badge/GitHub-181717?style=for-the-badge&logo=GitHub&logoColor=white"/>
    </a>
    <a href="https://pypi.org/project/zerohertzLib/">
        <img src="https://img.shields.io/badge/PyPI-3775A9?style=for-the-badge&logo=PyPI&logoColor=white"/>
    </a>
    <a href="https://jenkins.zerohertz.xyz/blue/organizations/jenkins/zerohertzLib/activity">
        <img src="https://img.shields.io/badge/Jenkins-D24939?style=for-the-badge&logo=Jenkins&logoColor=white"/>
    </a>
    <a href = "https://zerohertz.github.io/python-pkg-cicd/">
        <img src="https://img.shields.io/badge/Zerohertz's%20Blog-800a0a?style=for-the-badge&logo=beatsbydre&logoColor=white"/>
    </a>
    <a href="https://zerohertz.github.io/zerohertzLib/">
        <img src="https://img.shields.io/badge/Sphinx-000000?style=for-the-badge&logo=Sphinx&logoColor=white"/>
    </a>
    </br>
    <a href="https://pypi.org/project/zerohertzLib/">
        <img src="https://badge.fury.io/py/zerohertzLib.svg" alt="PyPI version">
    </a>
    <a href="https://pypi.org/project/zerohertzLib/">
        <img alt="PyPI wheel" src="https://img.shields.io/pypi/wheel/zerohertzLib">
    </a>
    <a href="https://github.com/psf/black">
        <img src="https://img.shields.io/badge/code%20style-black-black">
    </a>
    <a href="https://app.codacy.com/gh/Zerohertz/zerohertzLib/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade">
        <img src="https://app.codacy.com/project/badge/Grade/b08b1d140ee54ae1aa8ee251cb5888ff"/>
    </a>
</p>

```bash
$ sudo apt install python3-opencv -y
$ pip install zerohertzLib
```

```python
import zerohertzLib as zz
```

==> zerohertzLib-0.8.2.tar.gz: zerohertzLib-0.8.2/README.md <==
<p align="center">
    <img src="https://github-production-user-asset-6210df.s3.amazonaws.com/42334717/284166558-0ba4b755-39cc-48ee-ba3b-5c02f54c4ca7.png">
</p>

<h2 align = "center">
    ⚡ Zerohertz's Library ⚡
</h2>

<p align="center">
    </br>
    <a href="https://pypi.org/project/zerohertzLib/">
        <img src="https://img.shields.io/pypi/v/zerohertzLib?style=for-the-badge&logo=PyPI&logoColor=FFFFFF&labelColor=3775A9&color=007EC6" alt="PyPI version">
    </a>
    </br>
    <a href="https://github.com/Zerohertz/zerohertzLib">
        <img src="https://img.shields.io/badge/GitHub-181717?style=for-the-badge&logo=GitHub&logoColor=white"/>
    </a>
    <a href="https://jenkins.zerohertz.xyz/blue/organizations/jenkins/zerohertzLib/activity">
        <img src="https://img.shields.io/badge/Jenkins-D24939?style=for-the-badge&logo=Jenkins&logoColor=white"/>
    </a>
    <a href = "https://zerohertz.github.io/python-pkg-cicd/">
        <img src="https://img.shields.io/badge/Zerohertz's%20Blog-800a0a?style=for-the-badge&logo=beatsbydre&logoColor=white"/>
    </a>
    <a href="https://zerohertz.github.io/zerohertzLib/">
        <img src="https://img.shields.io/badge/Sphinx-000000?style=for-the-badge&logo=Sphinx&logoColor=white"/>
    </a>
    </br>
    <a href="https://github.com/Zerohertz/zerohertzLib/blob/master/LICENSE">
        <img src="https://img.shields.io/pypi/l/zerohertzLib", alt="LICENSE">
    </a>
    <a href="https://pypi.org/project/zerohertzLib/">
        <img alt="PyPI wheel" src="https://img.shields.io/pypi/wheel/zerohertzLib">
    </a>
    <a href="https://github.com/psf/black">
        <img src="https://img.shields.io/badge/code%20style-black-black">
    </a>
    <a href="https://app.codacy.com/gh/Zerohertz/zerohertzLib/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade">
        <img src="https://app.codacy.com/project/badge/Grade/b08b1d140ee54ae1aa8ee251cb5888ff"/>
    </a>
</p>

```bash
$ sudo apt install python3-opencv -y
$ pip install zerohertzLib
$ pip install zerohertzLib[api]
$ pip install zerohertzLib[mlops]
$ pip install zerohertzLib[quant]
$ pip install zerohertzLib[all]
```
<p align="center">
    <img src="https://github.com/Zerohertz/Zerohertz/assets/42334717/2ed7f05b-3542-4f1d-8267-4fe681235cb9" width="600"/>
</p>

```python
import zerohertzLib as zz
```
